/**
 * Copyright 2015 Google Inc. All Rights Reserved.
 * Use of this source code is governed by a BSD-style
 * license that can be found in the LICENSE file or at
 * https://github.com/firebase/superstatic/blob/master/LICENSE
 */
'use strict';

var slasher = require('glob-slasher');
var urlParser = require('fast-url-parser');
var patterns = require('../utils/patterns');

var normalizeConfig = function(config) {
  return config || [];
};

var matcher = function(rewrites) {
  return function(url) {
    for (var i = 0; i < rewrites.length; i++) {
      if (patterns.configMatcher(url, rewrites[i])) {
        return rewrites[i];
      }
    }
    return undefined;
  };
};

module.exports = function() {
  return function(req, res, next) {
    var rewrites = matcher(normalizeConfig(req.superstatic.rewrites));

    var pathname = urlParser.parse(req.url).pathname;
    var match = rewrites(slasher(pathname));

    if (!match) {
      return next();
    }

    res.statusCode = 200;

    return res.superstatic.handle({rewrite: match}, next);
  };
};
